% PKS Filter============================================================
%
% Inputs:
% x_old - old state vector, size (n,1)
% P_old - old covariance matrix, size (n,n)
% u - input data, size (1,n)
% d - desired signal or output, size (1)
% calA...calD - state transition matrices, see type.StatisticModel
%
% Outputs:
% x_new - new state vector
% P_new - new covariance matrix 
%
function [x_new, P_new]  = ...
    fcn_PKS(x_old, P_old, u, d, calA, R)
%
%==========================================================
% statistical model:
% xApos(t)     = calA x(t-1) (for random walk calA = I)
% x(t)         = xApos(t)  + v
% d(t)         = calC x(t) + w
%
% with calC    = u(t)
% with Cov(v)  = R
% with Cov(w)  = Q
%==========================================================  
%propagation
% calB = 0;
calC = u;
% calD = 0;
%time update
x_new = calA * x_old;
P_new = calA * P_old * calA';
%
e = d - (calC * x_new);
K = (P_new * calC') / (R + calC * P_new * calC');
P_new = 1/R*(P_new - K * calC * P_new); %[Ljung1999a, p.365]
x_new = x_new + K * e;
end % of function==========================================================