%==========================================================================
% Rekursive Least Squares Estimator for MISO Systems A*X=B
%
% Inputs:
% A-system input size (m,n)
% B-system output size (m,d) with d:=1 for single output
% X_old-old or initial parameter size (n,1)
% P_old-old or initial parameter covariance matrix size (n,n)
%
% Outputs:
% X_new-parameter update size (n,1)
% P_new-parameter covariance matrix update size (n,n)
%
function [X_new, P_new] = fcn_rls...
    (A, B, X_old, P_old, lambda)
%
[~, n] = size(A);
e = B - A * X_old; %a priori error
% RLS algorithm with standard single forgetting factor [Ljung1999] 
G = 1 / (lambda + (A * P_old * A'));
L = (P_old * A') * G;% gain vector, Kalman gain        
P_new = ((eye(n) - L * A) * P_old) / lambda; % covariance matrix 
X_new = X_old + P_new * (A'*e); % (L = P_new*A')
end